@@ -292,7 +292,7 @@
 <context>
     <name>Fm::AppChooserComboBox</name>
     <message>
-        <location filename="../../appchoosercombobox.cpp" line="78"/>
+        <location filename="../../appchoosercombobox.cpp" line="67"/>
         <source>Customize</source>
         <translation>Özelleştir</translation>
     </message>
@@ -308,25 +308,35 @@
 <context>
     <name>Fm::CreateNewMenu</name>
     <message>
-        <location filename="../../createnewmenu.cpp" line="29"/>
+        <location filename="../../createnewmenu.cpp" line="30"/>
         <source>Folder</source>
         <translation>Dizin</translation>
     </message>
     <message>
-        <location filename="../../createnewmenu.cpp" line="33"/>
+        <location filename="../../createnewmenu.cpp" line="34"/>
         <source>Blank File</source>
         <translation>Boş Dosya</translation>
     </message>
 </context>
+<context>
+    <name>Fm::DirListJob</name>
+    <message>
+        <location filename="../../core/dirlistjob.cpp" line="45"/>
+        <source>The specified directory &apos;%1&apos; is not valid</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Fm::DirTreeModel</name>
     <message>
-        <location filename="../../dirtreemodelitem.cpp" line="76"/>
+        <location filename="../../dirtreemodelitem.cpp" line="85"/>
         <source>Loading...</source>
         <translation>Yükleniyor...</translation>
     </message>
     <message>
-        <location filename="../../dirtreemodelitem.cpp" line="207"/>
+        <location filename="../../dirtreemodelitem.cpp" line="268"/>
+        <location filename="../../dirtreemodelitem.cpp" line="312"/>
+        <location filename="../../dirtreemodelitem.cpp" line="410"/>
         <source>&lt;No sub folders&gt;</source>
         <translation>&lt;Alt dizin yok&gt;</translation>
     </message>
@@ -334,17 +344,17 @@
 <context>
     <name>Fm::DirTreeView</name>
     <message>
-        <location filename="../../dirtreeview.cpp" line="207"/>
+        <location filename="../../dirtreeview.cpp" line="211"/>
         <source>Open in New T&amp;ab</source>
         <translation>Yeni Sekme&amp;de Aç</translation>
     </message>
     <message>
-        <location filename="../../dirtreeview.cpp" line="211"/>
+        <location filename="../../dirtreeview.cpp" line="215"/>
         <source>Open in New Win&amp;dow</source>
         <translation>Yeni &amp;Pencerede Aç</translation>
     </message>
     <message>
-        <location filename="../../dirtreeview.cpp" line="216"/>
+        <location filename="../../dirtreeview.cpp" line="220"/>
         <source>Open in Termina&amp;l</source>
         <translation>&amp;Uçbirimde Aç</translation>
     </message>
@@ -352,7 +362,7 @@
 <context>
     <name>Fm::DndActionMenu</name>
     <message>
-        <location filename="../../dndactionmenu.cpp" line="33"/>
+        <location filename="../../dndactionmenu.cpp" line="32"/>
         <source>Copy here</source>
         <translation>Buraya Kopyala</translation>
     </message>
@@ -362,12 +372,12 @@
         <translation>Buraya taşı</translation>
     </message>
     <message>
-        <location filename="../../dndactionmenu.cpp" line="37"/>
+        <location filename="../../dndactionmenu.cpp" line="38"/>
         <source>Create symlink here</source>
         <translation>Buraya sembolik bağlantı oluştur</translation>
     </message>
     <message>
-        <location filename="../../dndactionmenu.cpp" line="39"/>
+        <location filename="../../dndactionmenu.cpp" line="41"/>
         <source>Cancel</source>
         <translation>İptal</translation>
     </message>
@@ -375,7 +385,7 @@
 <context>
     <name>Fm::EditBookmarksDialog</name>
     <message>
-        <location filename="../../editbookmarksdialog.cpp" line="96"/>
+        <location filename="../../editbookmarksdialog.cpp" line="98"/>
         <source>New bookmark</source>
         <translation>Yeni yerimi</translation>
     </message>
@@ -383,14 +393,14 @@
 <context>
     <name>Fm::ExecFileDialog</name>
     <message>
-        <location filename="../../execfiledialog.cpp" line="39"/>
+        <location filename="../../execfiledialog.cpp" line="40"/>
         <source>This text file &apos;%1&apos; seems to be an executable script.
 What do you want to do with it?</source>
         <translation>Bu metin dosyası &apos;%1&apos; çalıştırılabilir bir betik gibi görünüyor.
 Çalıştırmak ister misiniz?</translation>
     </message>
     <message>
-        <location filename="../../execfiledialog.cpp" line="44"/>
+        <location filename="../../execfiledialog.cpp" line="45"/>
         <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
         <translation>Bu dosya &apos;%1&apos; çalıştırılabilir. Çalıştırmak ister misiniz?</translation>
     </message>
@@ -398,83 +408,83 @@ What do you want to do with it?</source>
 <context>
     <name>Fm::FileMenu</name>
     <message>
-        <location filename="../../filemenu.cpp" line="95"/>
+        <location filename="../../filemenu.cpp" line="82"/>
         <source>Open</source>
         <translation>Aç</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="99"/>
+        <location filename="../../filemenu.cpp" line="86"/>
         <source>Open With...</source>
         <translation>Birlikte Aç...</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="129"/>
+        <location filename="../../filemenu.cpp" line="114"/>
         <source>Other Applications</source>
         <translation>Diğer Uygulamalar</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="135"/>
+        <location filename="../../filemenu.cpp" line="120"/>
         <source>Create &amp;New</source>
         <translation>Ye&amp;ni Oluştur</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="155"/>
+        <location filename="../../filemenu.cpp" line="139"/>
         <source>&amp;Restore</source>
         <translation>&amp;Geri Yükle</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="161"/>
+        <location filename="../../filemenu.cpp" line="145"/>
         <source>Cut</source>
         <translation>Kes</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="165"/>
+        <location filename="../../filemenu.cpp" line="149"/>
         <source>Copy</source>
         <translation>Kopyala</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="169"/>
+        <location filename="../../filemenu.cpp" line="153"/>
         <source>Paste</source>
         <translation>Yapıştır</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="173"/>
-        <location filename="../../filemenu.cpp" line="375"/>
+        <location filename="../../filemenu.cpp" line="157"/>
+        <location filename="../../filemenu.cpp" line="348"/>
         <source>&amp;Move to Trash</source>
         <translation>&amp;Çöp Kutusuna Taşı</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="177"/>
+        <location filename="../../filemenu.cpp" line="161"/>
         <source>Rename</source>
         <translation>Yeniden Adlandır</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="209"/>
+        <location filename="../../filemenu.cpp" line="188"/>
         <source>Extract to...</source>
         <translation>Buraya çıkart...</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="214"/>
+        <location filename="../../filemenu.cpp" line="193"/>
         <source>Extract Here</source>
         <translation>Buraya çıkart</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="220"/>
+        <location filename="../../filemenu.cpp" line="199"/>
         <source>Compress</source>
         <translation>Sıkıştır</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="230"/>
+        <location filename="../../filemenu.cpp" line="209"/>
         <source>Properties</source>
         <translation>Özellikler</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="323"/>
+        <location filename="../../filemenu.cpp" line="297"/>
         <source>Output</source>
         <translation>Çıktı</translation>
     </message>
     <message>
-        <location filename="../../filemenu.cpp" line="375"/>
+        <location filename="../../filemenu.cpp" line="348"/>
         <source>&amp;Delete</source>
         <translation>&amp;Sil</translation>
     </message>
@@ -482,30 +492,30 @@ What do you want to do with it?</source>
 <context>
     <name>Fm::FileOperation</name>
     <message>
-        <location filename="../../fileoperation.cpp" line="220"/>
+        <location filename="../../fileoperation.cpp" line="227"/>
         <source>Error</source>
         <translation>Hata</translation>
     </message>
     <message>
-        <location filename="../../fileoperation.cpp" line="221"/>
+        <location filename="../../fileoperation.cpp" line="228"/>
         <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
 Do you want to delete them instead?</source>
         <translation>Bazı dosyalar çöğ kutusuna taşınamıyorlar.Çünkü dosya sistemi bu işlemi desteklemiyor. 
 Onun yerine silmek ister misiniz?</translation>
     </message>
     <message>
-        <location filename="../../fileoperation.cpp" line="262"/>
-        <location filename="../../fileoperation.cpp" line="278"/>
+        <location filename="../../fileoperation.cpp" line="270"/>
+        <location filename="../../fileoperation.cpp" line="287"/>
         <source>Confirm</source>
         <translation>Doğrula</translation>
     </message>
     <message>
-        <location filename="../../fileoperation.cpp" line="263"/>
+        <location filename="../../fileoperation.cpp" line="271"/>
         <source>Do you want to delete the selected files?</source>
         <translation>Seçilen dosyaları silmek istiyor musunuz?</translation>
     </message>
     <message>
-        <location filename="../../fileoperation.cpp" line="279"/>
+        <location filename="../../fileoperation.cpp" line="288"/>
         <source>Do you want to move the selected files to trash can?</source>
         <translation>Seçilen dosyaları çöp kutusuna taşımak istiyor musunuz?</translation>
     </message>
@@ -583,7 +593,7 @@ Onun yerine silmek ister misiniz?</translation>
         <translation>Aşağıdaki dosyalar çöp kutusundan geri yüklenebilir:</translation>
     </message>
     <message>
-        <location filename="../../fileoperationdialog.cpp" line="137"/>
+        <location filename="../../fileoperationdialog.cpp" line="134"/>
         <source>Error</source>
         <translation>Hata</translation>
     </message>
@@ -591,47 +601,57 @@ Onun yerine silmek ister misiniz?</translation>
 <context>
     <name>Fm::FilePropsDialog</name>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="154"/>
+        <location filename="../../filepropsdialog.cpp" line="156"/>
         <source>View folder content</source>
         <translation>Dizin içeriğini görebilir</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="155"/>
+        <location filename="../../filepropsdialog.cpp" line="157"/>
         <source>View and modify folder content</source>
         <translation>Dizin içeriğini görebilir ve değiştirebilir</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="159"/>
+        <location filename="../../filepropsdialog.cpp" line="161"/>
         <source>Read</source>
         <translation>Okuyabilir</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="160"/>
+        <location filename="../../filepropsdialog.cpp" line="162"/>
         <source>Read and write</source>
         <translation>Okuyabilir ve Yazabilir</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="162"/>
+        <location filename="../../filepropsdialog.cpp" line="164"/>
         <source>Forbidden</source>
         <translation>İzin yok</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="266"/>
+        <location filename="../../filepropsdialog.cpp" line="281"/>
         <source>Files of different types</source>
         <translation>Farklı türlerin dosyaları</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="296"/>
+        <location filename="../../filepropsdialog.cpp" line="304"/>
         <source>Multiple Files</source>
         <translation>Çoklu Dosyalar</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="424"/>
+        <location filename="../../filepropsdialog.cpp" line="380"/>
+        <source>Select an icon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../filepropsdialog.cpp" line="382"/>
+        <source>Images (*.png *.xpm *.svg *.svgz )</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../filepropsdialog.cpp" line="478"/>
         <source>Apply changes</source>
         <translation>Değişiklikleri uygula</translation>
     </message>
     <message>
-        <location filename="../../filepropsdialog.cpp" line="425"/>
+        <location filename="../../filepropsdialog.cpp" line="479"/>
         <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
         <translation>Bu değişiklikleri tüm dosya ve alt dizinlere uygulamak istiyor musunuz?</translation>
     </message>
@@ -639,17 +659,17 @@ Onun yerine silmek ister misiniz?</translation>
 <context>
     <name>Fm::FileSearchDialog</name>
     <message>
-        <location filename="../../filesearchdialog.cpp" line="122"/>
+        <location filename="../../filesearchdialog.cpp" line="128"/>
         <source>Error</source>
         <translation>Hata</translation>
     </message>
     <message>
-        <location filename="../../filesearchdialog.cpp" line="122"/>
+        <location filename="../../filesearchdialog.cpp" line="128"/>
         <source>You should add at least one directory to search.</source>
         <translation>Arama yapmak için en az bir dizin eklemelisiniz.</translation>
     </message>
     <message>
-        <location filename="../../filesearchdialog.cpp" line="129"/>
+        <location filename="../../filesearchdialog.cpp" line="135"/>
         <source>Select a folder</source>
         <translation>Bir dizin seç</translation>
     </message>
@@ -687,57 +707,57 @@ Onun yerine silmek ister misiniz?</translation>
         <translation>Gizli Dosyaları Göster</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="100"/>
+        <location filename="../../foldermenu.cpp" line="94"/>
         <source>Folder Pr&amp;operties</source>
         <translation>Dizin Ö&amp;zellikleri</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="143"/>
+        <location filename="../../foldermenu.cpp" line="137"/>
         <source>Output</source>
         <translation>Çıktı</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="168"/>
+        <location filename="../../foldermenu.cpp" line="160"/>
         <source>By File Name</source>
         <translation>Dosya Adına Göre</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="169"/>
+        <location filename="../../foldermenu.cpp" line="161"/>
         <source>By Modification Time</source>
         <translation>Değiştirme Tarihine Göre</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="170"/>
+        <location filename="../../foldermenu.cpp" line="162"/>
         <source>By File Size</source>
         <translation>Dosya Boyutuna Göre</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="171"/>
+        <location filename="../../foldermenu.cpp" line="163"/>
         <source>By File Type</source>
         <translation>Dosya Türüne Göre</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="172"/>
+        <location filename="../../foldermenu.cpp" line="164"/>
         <source>By File Owner</source>
         <translation>Sahibine Göre</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="184"/>
+        <location filename="../../foldermenu.cpp" line="176"/>
         <source>Ascending</source>
         <translation>Artan</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="189"/>
+        <location filename="../../foldermenu.cpp" line="181"/>
         <source>Descending</source>
         <translation>Azalan</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="204"/>
+        <location filename="../../foldermenu.cpp" line="198"/>
         <source>Folder First</source>
         <translation>Önce Dizin</translation>
     </message>
     <message>
-        <location filename="../../foldermenu.cpp" line="213"/>
+        <location filename="../../foldermenu.cpp" line="208"/>
         <source>Case Sensitive</source>
         <translation>Büyük Küçük Harf Duyarlı</translation>
     </message>
@@ -745,27 +765,27 @@ Onun yerine silmek ister misiniz?</translation>
 <context>
     <name>Fm::FolderModel</name>
     <message>
-        <location filename="../../foldermodel.cpp" line="248"/>
+        <location filename="../../foldermodel.cpp" line="242"/>
         <source>Name</source>
         <translation>İsim</translation>
     </message>
     <message>
-        <location filename="../../foldermodel.cpp" line="251"/>
+        <location filename="../../foldermodel.cpp" line="245"/>
         <source>Type</source>
         <translation>Tür</translation>
     </message>
     <message>
-        <location filename="../../foldermodel.cpp" line="254"/>
+        <location filename="../../foldermodel.cpp" line="248"/>
         <source>Size</source>
         <translation>Boyut</translation>
     </message>
     <message>
-        <location filename="../../foldermodel.cpp" line="257"/>
+        <location filename="../../foldermodel.cpp" line="251"/>
         <source>Modified</source>
         <translation>Değiştirildi</translation>
     </message>
     <message>
-        <location filename="../../foldermodel.cpp" line="260"/>
+        <location filename="../../foldermodel.cpp" line="254"/>
         <source>Owner</source>
         <translation>Sahip</translation>
     </message>
@@ -794,12 +814,12 @@ Onun yerine silmek ister misiniz?</translation>
 <context>
     <name>Fm::PathBar</name>
     <message>
-        <location filename="../../pathbar.cpp" line="123"/>
+        <location filename="../../pathbar.cpp" line="126"/>
         <source>&amp;Edit Path</source>
         <translation>Yolu Düz&amp;enle</translation>
     </message>
     <message>
-        <location filename="../../pathbar.cpp" line="126"/>
+        <location filename="../../pathbar.cpp" line="129"/>
         <source>&amp;Copy Path</source>
         <translation>Yolu &amp;Kopyala</translation>
     </message>
@@ -807,42 +827,42 @@ Onun yerine silmek ister misiniz?</translation>
 <context>
     <name>Fm::PlacesModel</name>
     <message>
-        <location filename="../../placesmodel.cpp" line="40"/>
+        <location filename="../../placesmodel.cpp" line="44"/>
         <source>Places</source>
         <translation>Konumlar</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="48"/>
+        <location filename="../../placesmodel.cpp" line="52"/>
         <source>Desktop</source>
         <translation>Masaüstü</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="57"/>
+        <location filename="../../placesmodel.cpp" line="60"/>
         <source>Computer</source>
         <translation>Bilgisayar</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="70"/>
+        <location filename="../../placesmodel.cpp" line="72"/>
         <source>Applications</source>
         <translation>Uygulamalar</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="82"/>
+        <location filename="../../placesmodel.cpp" line="81"/>
         <source>Network</source>
         <translation>Ağ</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="90"/>
+        <location filename="../../placesmodel.cpp" line="88"/>
         <source>Devices</source>
         <translation>Aygıtlar</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="143"/>
+        <location filename="../../placesmodel.cpp" line="142"/>
         <source>Bookmarks</source>
         <translation>Yer İmleri</translation>
     </message>
     <message>
-        <location filename="../../placesmodel.cpp" line="244"/>
+        <location filename="../../placesmodel.cpp" line="231"/>
         <source>Trash</source>
         <translation>Çöp</translation>
     </message>
@@ -860,43 +880,43 @@ Onun yerine silmek ister misiniz?</translation>
         <translation>Yeni Pencerede Aç</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="368"/>
+        <location filename="../../placesview.cpp" line="370"/>
         <source>Empty Trash</source>
         <translation>Çöp Kutusunu Boşalt</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="377"/>
+        <location filename="../../placesview.cpp" line="379"/>
         <source>Move Bookmark Up</source>
         <translation>Yer İmini Yukarı Taşı</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="382"/>
+        <location filename="../../placesview.cpp" line="384"/>
         <source>Move Bookmark Down</source>
         <translation>Yer İmini Aşağı Taşı</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="386"/>
+        <location filename="../../placesview.cpp" line="388"/>
         <source>Rename Bookmark</source>
         <translation>Yer imini yeniden adlandır</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="389"/>
+        <location filename="../../placesview.cpp" line="391"/>
         <source>Remove Bookmark</source>
         <translation>Yer imini sil</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="398"/>
-        <location filename="../../placesview.cpp" line="415"/>
+        <location filename="../../placesview.cpp" line="400"/>
+        <location filename="../../placesview.cpp" line="417"/>
         <source>Unmount</source>
         <translation>Ayır</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="402"/>
+        <location filename="../../placesview.cpp" line="404"/>
         <source>Mount</source>
         <translation>Bağla</translation>
     </message>
     <message>
-        <location filename="../../placesview.cpp" line="408"/>
+        <location filename="../../placesview.cpp" line="410"/>
         <source>Eject</source>
         <translation>Çıkart</translation>
     </message>
@@ -935,26 +955,22 @@ Değiştirild: %2</translation>
 <context>
     <name>Fm::SidePane</name>
     <message>
-        <location filename="../../sidepane.cpp" line="47"/>
-        <location filename="../../sidepane.cpp" line="127"/>
+        <location filename="../../sidepane.cpp" line="46"/>
         <source>Places</source>
         <translation>Konumlar</translation>
     </message>
     <message>
-        <location filename="../../sidepane.cpp" line="48"/>
-        <location filename="../../sidepane.cpp" line="129"/>
+        <location filename="../../sidepane.cpp" line="47"/>
         <source>Directory Tree</source>
         <translation>Dizin Ağacı</translation>
     </message>
     <message>
-        <location filename="../../sidepane.cpp" line="137"/>
         <source>Shows list of common places, devices, and bookmarks in sidebar</source>
-        <translation>Kenar çubuğunda genel yerlerin, aygıtların ve yer imlerinin bir listesini gösterir</translation>
+        <translation type="vanished">Kenar çubuğunda genel yerlerin, aygıtların ve yer imlerinin bir listesini gösterir</translation>
     </message>
     <message>
-        <location filename="../../sidepane.cpp" line="139"/>
         <source>Shows tree of directories in sidebar</source>
-        <translation>Kenar çubuğunda dizin ağacını gösterir</translation>
+        <translation type="vanished">Kenar çubuğunda dizin ağacını gösterir</translation>
     </message>
 </context>
 <context>
@@ -1008,59 +1024,64 @@ Değiştirild: %2</translation>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../utilities.cpp" line="120"/>
+        <location filename="../../utilities.cpp" line="149"/>
         <source>Rename File</source>
         <translation>Dosyayı Yeniden Adlandır</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="121"/>
+        <location filename="../../utilities.cpp" line="150"/>
         <source>Please enter a new name:</source>
         <translation>Lütfen yeni bir isim girin:</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="149"/>
-        <location filename="../../utilities.cpp" line="225"/>
-        <location filename="../../mountoperation.cpp" line="185"/>
-        <location filename="../../filepropsdialog.cpp" line="450"/>
-        <location filename="../../filelauncher.cpp" line="117"/>
+        <location filename="../../utilities.cpp" line="143"/>
+        <location filename="../../utilities.cpp" line="232"/>
+        <location filename="../../mountoperation.cpp" line="186"/>
+        <location filename="../../filepropsdialog.cpp" line="503"/>
+        <location filename="../../filelauncher.cpp" line="139"/>
         <source>Error</source>
         <translation>Hata</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="161"/>
+        <location filename="../../utilities.cpp" line="174"/>
         <source>Create Folder</source>
         <translation>Dizin Oluştur</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="162"/>
+        <location filename="../../utilities.cpp" line="175"/>
         <source>Create File</source>
         <translation>Dosya Oluştur</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="166"/>
+        <location filename="../../utilities.cpp" line="179"/>
         <source>Please enter a new file name:</source>
         <translation>Lütfen yeni bir dosya adı girin:</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="167"/>
+        <location filename="../../utilities.cpp" line="180"/>
         <source>New text file</source>
         <translation>Yeni metin dosyası</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="171"/>
+        <location filename="../../utilities.cpp" line="184"/>
         <source>Please enter a new folder name:</source>
         <translation>Lütfen yeni bir dizin adı girin:</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="172"/>
+        <location filename="../../utilities.cpp" line="185"/>
         <source>New folder</source>
         <translation>Yeni dizin</translation>
     </message>
     <message>
-        <location filename="../../utilities.cpp" line="177"/>
+        <location filename="../../utilities.cpp" line="190"/>
         <source>Enter a name for the new %1:</source>
         <translation>Yeni %1 için bir isim girin:</translation>
     </message>
+    <message>
+        <location filename="../../filepropsdialog.cpp" line="520"/>
+        <source>Custom Icon Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RenameDialog</name>
@@ -1125,7 +1146,7 @@ Değiştirild: %2</translation>
     <message>
         <location filename="../../filesearch.ui" line="35"/>
         <source>File Name Patterns:</source>
-        <translation type="unfinished"></translation>
+        <translation>Dosya Adı Modelleri:</translation>
     </message>
     <message>
         <location filename="../../filesearch.ui" line="41"/>
@@ -1145,7 +1166,7 @@ Değiştirild: %2</translation>
     <message>
         <location filename="../../filesearch.ui" line="65"/>
         <source>Places to Search:</source>
-        <translation type="unfinished"></translation>
+        <translation>Aradığınız Yerler:</translation>
     </message>
     <message>
         <location filename="../../filesearch.ui" line="78"/>
@@ -1258,13 +1279,13 @@ Değiştirild: %2</translation>
         <location filename="../../filesearch.ui" line="313"/>
         <location filename="../../filesearch.ui" line="343"/>
         <source>MiB</source>
-        <translation type="unfinished">MBit</translation>
+        <translation>MB</translation>
     </message>
     <message>
         <location filename="../../filesearch.ui" line="318"/>
         <location filename="../../filesearch.ui" line="348"/>
         <source>GiB</source>
-        <translation type="unfinished"></translation>
+        <translation>GB</translation>
     </message>
     <message>
         <location filename="../../filesearch.ui" line="268"/>
