@@ -9,11 +9,11 @@
     </message>
     <message>
         <source>Search:</source>
-        <translation>Pesquisar:</translation>
+        <translation type="vanished">Pesquisar:</translation>
     </message>
     <message>
         <source>Add Widget</source>
-        <translation>Adicionar widget</translation>
+        <translation type="vanished">Adicionar widget</translation>
     </message>
     <message>
         <source>Add plugin</source>
@@ -21,7 +21,7 @@
     </message>
     <message>
         <source>Close</source>
-        <translation>Fechar</translation>
+        <translation type="vanished">Fechar</translation>
     </message>
 </context>
 <context>
@@ -36,52 +36,52 @@
     <name>LXQt::AboutDialogPrivate</name>
     <message>
         <source>Version: %1</source>
-        <translation>Versão: %1</translation>
+        <translation type="vanished">Versão: %1</translation>
     </message>
     <message>
         <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
         <comment>About dialog, &apos;About&apos; tab text</comment>
-        <translation>Ambiente de trabalho rápido simples e fácil de utilizar, baseado na tecnologia Qt.</translation>
+        <translation type="vanished">Ambiente de trabalho rápido simples e fácil de utilizar, baseado na tecnologia Qt.</translation>
     </message>
     <message>
         <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
         <comment>About dialog, &apos;About&apos; tab text</comment>
-        <translation>O LXQt não seria possível sem a ajuda dos colaboradores do projeto &lt;a %1&gt;Razor-qt&lt;/a&gt;.</translation>
+        <translation type="vanished">O LXQt não seria possível sem a ajuda dos colaboradores do projeto &lt;a %1&gt;Razor-qt&lt;/a&gt;.</translation>
     </message>
     <message>
         <source>Copyright: %1-%2 %3</source>
         <comment>About dialog, &apos;About&apos; tab text</comment>
-        <translation>Direitos de autor: %1-%2 %3</translation>
+        <translation type="vanished">Direitos de autor: %1-%2 %3</translation>
     </message>
     <message>
         <source>Homepage: %1</source>
         <comment>About dialog, &apos;About&apos; tab text</comment>
-        <translation>Página web: %1</translation>
+        <translation type="vanished">Página web: %1</translation>
     </message>
     <message>
         <source>License: %1</source>
         <comment>About dialog, &apos;About&apos; tab text</comment>
-        <translation>Licença: %1</translation>
+        <translation type="vanished">Licença: %1</translation>
     </message>
     <message>
         <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
         <comment>About dialog, &apos;Authors&apos; tab text</comment>
-        <translation>O LXQt é desenvolvido pelos &lt;a %1&gt;colaboradores da equipa LXQt&lt;/a&gt;.</translation>
+        <translation type="vanished">O LXQt é desenvolvido pelos &lt;a %1&gt;colaboradores da equipa LXQt&lt;/a&gt;.</translation>
     </message>
     <message>
         <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
         <comment>About dialog, &apos;Authors&apos; tab text</comment>
-        <translation>Se quiser ajudar no desenvolvimento, &lt;a %1&gt;pode integrar a nossa equipa&lt;/a&gt;.</translation>
+        <translation type="vanished">Se quiser ajudar no desenvolvimento, &lt;a %1&gt;pode integrar a nossa equipa&lt;/a&gt;.</translation>
     </message>
     <message>
         <source>Special thanks to:</source>
         <comment>About dialog, &apos;Thanks&apos; tab text</comment>
-        <translation>Um especial obrigado:</translation>
+        <translation type="vanished">Um especial obrigado:</translation>
     </message>
     <message>
         <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
         <comment>About dialog, &apos;Translations&apos; tab text</comment>
-        <translation>O LXQt está traduzido em diversos idiomas graças ao trabalho desenvolvido pelas equipas de tradução de todo o mundo.</translation>
+        <translation type="vanished">O LXQt está traduzido em diversos idiomas graças ao trabalho desenvolvido pelas equipas de tradução de todo o mundo.</translation>
     </message>
     <message>
         <source>Yes</source>
@@ -157,18 +157,18 @@
     <name>LXQt::AddPluginDialog</name>
     <message>
         <source>(%1 active)</source>
-        <translation>(%1 ativo)</translation>
+        <translation type="vanished">(%1 ativo)</translation>
     </message>
 </context>
 <context>
     <name>LXQt::MessageBox</name>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="70"/>
+        <location filename="../../lxqtpowermanager.cpp" line="74"/>
         <source>LXQt Power Manager Error</source>
         <translation>Erro do gestor de energia do LXQt</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="70"/>
+        <location filename="../../lxqtpowermanager.cpp" line="74"/>
         <source>Hibernate failed.</source>
         <translation>Falha ao hibernar.</translation>
     </message>
@@ -184,93 +184,93 @@
 <context>
     <name>LXQt::PowerManager</name>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="112"/>
+        <location filename="../../lxqtpowermanager.cpp" line="117"/>
         <source>Hibernate</source>
         <translation>Hibernar</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="119"/>
+        <location filename="../../lxqtpowermanager.cpp" line="124"/>
         <source>Suspend</source>
         <translation>Suspender</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="126"/>
+        <location filename="../../lxqtpowermanager.cpp" line="131"/>
         <source>Reboot</source>
         <translation>Reiniciar</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="133"/>
+        <location filename="../../lxqtpowermanager.cpp" line="138"/>
         <source>Shutdown</source>
         <translation>Desligar</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="140"/>
+        <location filename="../../lxqtpowermanager.cpp" line="145"/>
         <source>Logout</source>
         <translation>Terminar sessão</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="152"/>
+        <location filename="../../lxqtpowermanager.cpp" line="157"/>
         <source>LXQt Session Suspend</source>
         <translation>Suspender</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="153"/>
+        <location filename="../../lxqtpowermanager.cpp" line="158"/>
         <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
         <translation>Pretende mesmo suspender o computador?&lt;p&gt;A suspensão deixa o computador num estado de energia baixa. O estado do sistema não é guardado se faltar a energia.</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="162"/>
+        <location filename="../../lxqtpowermanager.cpp" line="167"/>
         <source>LXQt Session Hibernate</source>
         <translation>Hibernar</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="163"/>
+        <location filename="../../lxqtpowermanager.cpp" line="168"/>
         <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
         <translation>Pretende mesmo hibernar o computador?&lt;p&gt;A hibernação deixa o computador num estado de energia baixa. O estado do sistema é guardado se faltar a energia.</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="172"/>
+        <location filename="../../lxqtpowermanager.cpp" line="177"/>
         <source>LXQt Session Reboot</source>
         <translation>Reiniciar</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="173"/>
+        <location filename="../../lxqtpowermanager.cpp" line="178"/>
         <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
         <translation>Pretende mesmo reiniciar o computador? Os trabalhos não guardados serão perdidos...</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="182"/>
+        <location filename="../../lxqtpowermanager.cpp" line="187"/>
         <source>LXQt Session Shutdown</source>
         <translation>Desligar</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="183"/>
+        <location filename="../../lxqtpowermanager.cpp" line="188"/>
         <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
         <translation>Pretende mesmo desligar o computador? Os trabalhos não guardados serão perdidos...</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="192"/>
+        <location filename="../../lxqtpowermanager.cpp" line="197"/>
         <source>LXQt Session Logout</source>
         <translation>Terminar sessão</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="193"/>
+        <location filename="../../lxqtpowermanager.cpp" line="198"/>
         <source>Do you want to really logout? All unsaved work will be lost...</source>
         <translation>Pretende mesmo terminar a sessão? Os trabalhos não guardados serão perdidos...</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="201"/>
         <location filename="../../lxqtpowermanager.cpp" line="206"/>
+        <location filename="../../lxqtpowermanager.cpp" line="211"/>
         <source>LXQt Power Manager Error</source>
         <translation>Erro do gestor de energia do LXQt</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="201"/>
+        <location filename="../../lxqtpowermanager.cpp" line="206"/>
         <source>Hibernate failed.</source>
         <translation>Falha ao hibernar.</translation>
     </message>
     <message>
-        <location filename="../../lxqtpowermanager.cpp" line="206"/>
+        <location filename="../../lxqtpowermanager.cpp" line="211"/>
         <source>Suspend failed.</source>
         <translation>Falha ao suspender.</translation>
     </message>
@@ -278,57 +278,57 @@
 <context>
     <name>LXQt::ScreenSaver</name>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="51"/>
+        <location filename="../../lxqtscreensaver.cpp" line="236"/>
         <source>Lock Screen</source>
         <translation>Bloquear ecrã</translation>
     </message>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="77"/>
+        <location filename="../../lxqtscreensaver.cpp" line="156"/>
         <source>Screen Saver Error</source>
         <translation>Erro de proteção de ecrã</translation>
     </message>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="83"/>
-        <location filename="../../lxqtscreensaver.cpp" line="89"/>
-        <location filename="../../lxqtscreensaver.cpp" line="96"/>
+        <location filename="../../lxqtscreensaver.cpp" line="162"/>
+        <location filename="../../lxqtscreensaver.cpp" line="168"/>
+        <location filename="../../lxqtscreensaver.cpp" line="175"/>
         <source>Screen Saver Activation Error</source>
         <translation>Erro ao ativar a proteção de ecrã</translation>
     </message>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="97"/>
+        <location filename="../../lxqtscreensaver.cpp" line="176"/>
         <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
         <translation>Ocorreu um erro ao iniciar a proteção do ecrã. Erro desconhecido - valor de retorno não documentado em xdg-screensaver: %1.</translation>
     </message>
     <message>
         <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
-        <translation>Ocorreu um erro ao iniciar a proteção de ecrã. O xdg-screensaver terminou abruptamente.</translation>
+        <translation type="vanished">Ocorreu um erro ao iniciar a proteção de ecrã. O xdg-screensaver terminou abruptamente.</translation>
     </message>
     <message>
         <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
-        <translation>Ocorreu um erro ao iniciar a proteção de ecrã. O xdg-screensaver não está instalado corretamente.</translation>
+        <translation type="vanished">Ocorreu um erro ao iniciar a proteção de ecrã. O xdg-screensaver não está instalado corretamente.</translation>
     </message>
     <message>
         <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
-        <translation>Ocorreu um erro ao iniciar a proteção de ecrã. O xdg-screensaver não foi iniciado.</translation>
+        <translation type="vanished">Ocorreu um erro ao iniciar a proteção de ecrã. O xdg-screensaver não foi iniciado.</translation>
     </message>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="78"/>
+        <location filename="../../lxqtscreensaver.cpp" line="157"/>
         <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
         <translation>Ocorreu um erro ao iniciar a proteção de ecrã. Existem erros de sintaxe nos argumentos xdg-screensaver.</translation>
     </message>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="84"/>
+        <location filename="../../lxqtscreensaver.cpp" line="163"/>
         <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
         <translation>Ocorreu um erro ao iniciar a proteção de ecrã. Certifique-se de que xdg-screensaver está instalado e em execução.</translation>
     </message>
     <message>
-        <location filename="../../lxqtscreensaver.cpp" line="90"/>
+        <location filename="../../lxqtscreensaver.cpp" line="169"/>
         <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
         <translation>Ocorreu um erro ao iniciar a proteção de ecrã. Erro na ação &apos;activate&apos;. Certifique-se de que xdg-screensaver está instalado e em execução.</translation>
     </message>
     <message>
         <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
-        <translation>Ocorreu um erro ao iniciar a proteção do ecrã. Erro desconhecido - valor de retorno não documentado em xdg-screensaver = %1.</translation>
+        <translation type="vanished">Ocorreu um erro ao iniciar a proteção do ecrã. Erro desconhecido - valor de retorno não documentado em xdg-screensaver = %1.</translation>
     </message>
 </context>
 <context>
@@ -345,20 +345,20 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="91"/>
-        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="141"/>
+        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
+        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
         <source>Power Manager Error</source>
         <translation>Erro do gestor de energia</translation>
     </message>
     <message>
-        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="92"/>
-        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="142"/>
+        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
+        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
         <source>QDBusInterface is invalid</source>
         <translation>A interface QDBus não é válida</translation>
     </message>
     <message>
-        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="106"/>
-        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="156"/>
+        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
+        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
         <source>Power Manager Error (D-BUS call)</source>
         <translation>Erro do gestor de energia (D-BUS)</translation>
     </message>
@@ -367,36 +367,36 @@
     <name>about</name>
     <message>
         <source> About LXQt</source>
-        <translation> Sobre o LXQt</translation>
+        <translation type="vanished"> Sobre o LXQt</translation>
     </message>
     <message>
         <source>About</source>
         <comment>About dialog, Tab title </comment>
-        <translation>Sobre</translation>
+        <translation type="vanished">Sobre</translation>
     </message>
     <message>
         <source>Authors</source>
         <comment>About dialog, Tab title</comment>
-        <translation>Autores</translation>
+        <translation type="vanished">Autores</translation>
     </message>
     <message>
         <source>Thanks</source>
         <comment>About dialog, Tab title</comment>
-        <translation>Agradecimentos</translation>
+        <translation type="vanished">Agradecimentos</translation>
     </message>
     <message>
         <source>Translations</source>
         <comment>About dialog, Tab title</comment>
-        <translation>Traduções</translation>
+        <translation type="vanished">Traduções</translation>
     </message>
     <message>
         <source>Technical Info</source>
         <comment>About dialog, Tab title</comment>
-        <translation>Informações técnicas</translation>
+        <translation type="vanished">Informações técnicas</translation>
     </message>
     <message>
         <source>Copy to clipboard</source>
-        <translation>Copiar para a área de transferência</translation>
+        <translation type="vanished">Copiar para a área de transferência</translation>
     </message>
 </context>
 </TS>
