@@ -1,15 +1,15 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="uk">
+<TS version="2.1" language="uk">
 <context>
     <name>LxImage::Application</name>
     <message>
-        <location filename="../../application.cpp" line="89"/>
+        <location filename="../../application.cpp" line="91"/>
         <source>Take a screenshot</source>
         <translation>Зробити знімок</translation>
     </message>
     <message>
-        <location filename="../../application.cpp" line="93"/>
+        <location filename="../../application.cpp" line="95"/>
         <source>[FILE1, FILE2,...]</source>
         <translation>[ФАЙЛ1, ФАЙЛ2,...]</translation>
     </message>
@@ -17,12 +17,12 @@
 <context>
     <name>LxImage::MainWindow</name>
     <message>
-        <location filename="../../mainwindow.cpp" line="148"/>
+        <location filename="../../mainwindow.cpp" line="143"/>
         <source>About</source>
         <translation>Про програму</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="149"/>
+        <location filename="../../mainwindow.cpp" line="144"/>
         <source>LXImage - a simple and fast image viewer
 
 Copyright (C) 2013
@@ -39,59 +39,64 @@ Copyright (C) 2013
 Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="242"/>
+        <location filename="../../mainwindow.cpp" line="253"/>
         <source>Open File</source>
         <translation>Відкрити файл</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="243"/>
-        <location filename="../../mainwindow.cpp" line="264"/>
+        <location filename="../../mainwindow.cpp" line="254"/>
+        <location filename="../../mainwindow.cpp" line="281"/>
         <source>Image files (%1)</source>
         <translation>Файли зображень (%1)</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="264"/>
+        <location filename="../../mainwindow.cpp" line="260"/>
+        <source>Open directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.cpp" line="281"/>
         <source>Save File</source>
         <translation>Зберегти файл</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="530"/>
+        <location filename="../../mainwindow.cpp" line="537"/>
         <source>[*]%1 (Loading...) - Image Viewer</source>
         <translation>[*]%1 (Завантаження...) - Переглядач малюнків</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="535"/>
+        <location filename="../../mainwindow.cpp" line="542"/>
         <source>[*]%1 (Failed to Load) - Image Viewer</source>
         <translation>[*]%1 (Не вдалося завантажити) - Переглядач малюнків</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="539"/>
+        <location filename="../../mainwindow.cpp" line="546"/>
         <source>[*]%1 (%2x%3) - Image Viewer</source>
         <translation>[*]%1 (%2x%3) - Переглядач малюнків</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="576"/>
+        <location filename="../../mainwindow.cpp" line="582"/>
         <source>[*]Image Viewer</source>
         <translation>[*]Переглядач малюнків</translation>
     </message>
     <message>
         <source>%1 (Loading...) - Image Viewer</source>
-        <translation>%1 (Завантаження...) - Переглядач зображень</translation>
+        <translation type="vanished">%1 (Завантаження...) - Переглядач зображень</translation>
     </message>
     <message>
         <source>%1 (Failed to Load) - Image Viewer</source>
-        <translation>%1 (Невдача завантаження) - Переглядач зображень</translation>
+        <translation type="vanished">%1 (Невдача завантаження) - Переглядач зображень</translation>
     </message>
     <message>
         <source>%1 (%2x%3) - Image Viewer</source>
-        <translation>%1 (%2x%3) - Переглядач зображень</translation>
+        <translation type="vanished">%1 (%2x%3) - Переглядач зображень</translation>
     </message>
     <message>
         <source>Image Viewer</source>
-        <translation>Переглядач зображень</translation>
+        <translation type="vanished">Переглядач зображень</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.cpp" line="819"/>
+        <location filename="../../mainwindow.cpp" line="842"/>
         <source>Thumbnails</source>
         <translation>Значки</translation>
     </message>
@@ -104,252 +109,271 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
         <translation>Переглядач зображень</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="159"/>
+        <location filename="../../mainwindow.ui" line="160"/>
         <source>&amp;About</source>
         <translation>&amp;Про програму</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="169"/>
+        <location filename="../../mainwindow.ui" line="170"/>
         <source>&amp;Open File</source>
         <translation>&amp;Відкрити файл</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="172"/>
+        <location filename="../../mainwindow.ui" line="173"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="182"/>
+        <location filename="../../mainwindow.ui" line="183"/>
         <source>&amp;Save</source>
         <translation>&amp;Зберегти</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="185"/>
+        <location filename="../../mainwindow.ui" line="186"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="195"/>
+        <location filename="../../mainwindow.ui" line="196"/>
         <source>Save &amp;As</source>
         <translation>Зберегти &amp;як</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="198"/>
+        <location filename="../../mainwindow.ui" line="199"/>
         <source>Ctrl+A</source>
         <translation>Ctrl+A</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="208"/>
+        <location filename="../../mainwindow.ui" line="209"/>
         <source>&amp;Close</source>
         <translation>&amp;Закрити</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="211"/>
+        <location filename="../../mainwindow.ui" line="212"/>
         <source>Ctrl+W</source>
         <translation>Ctrl+W</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="221"/>
+        <location filename="../../mainwindow.ui" line="222"/>
         <source>Zoom &amp;In</source>
         <translation>З&amp;більшити</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="224"/>
         <source>Ctrl++</source>
-        <translation>Ctrl++</translation>
+        <translation type="vanished">Ctrl++</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="234"/>
+        <location filename="../../mainwindow.ui" line="235"/>
         <source>Zoom &amp;Out</source>
         <translation>&amp;Зменшити</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="237"/>
+        <location filename="../../mainwindow.ui" line="238"/>
         <source>Ctrl+-</source>
         <translation>Ctrl+-</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="247"/>
+        <location filename="../../mainwindow.ui" line="248"/>
         <source>&amp;Copy to Clipboard</source>
         <translation>&amp;Копіювати до буфера</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="257"/>
-        <location filename="../../mainwindow.ui" line="260"/>
+        <location filename="../../mainwindow.ui" line="258"/>
+        <location filename="../../mainwindow.ui" line="261"/>
         <source>Next File</source>
         <translation>Наступний файл</translation>
     </message>
     <message>
         <source>Right</source>
-        <translation>Праворуч</translation>
+        <translation type="vanished">Праворуч</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="273"/>
-        <location filename="../../mainwindow.ui" line="276"/>
+        <location filename="../../mainwindow.ui" line="274"/>
+        <location filename="../../mainwindow.ui" line="277"/>
         <source>Previous File</source>
         <translation>Попередній Файл</translation>
     </message>
     <message>
         <source>Left</source>
-        <translation>Ліворуч</translation>
+        <translation type="vanished">Ліворуч</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="263"/>
+        <location filename="../../mainwindow.ui" line="225"/>
+        <source>Ctrl+=</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="264"/>
         <source>PgDown</source>
         <translation>PgDown</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="279"/>
+        <location filename="../../mainwindow.ui" line="280"/>
         <source>PgUp</source>
         <translation>PgUp</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="289"/>
+        <location filename="../../mainwindow.ui" line="290"/>
         <source>Original Size</source>
         <translation>Оригінальний розмір</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="299"/>
+        <location filename="../../mainwindow.ui" line="293"/>
+        <source>Ctrl+0</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="303"/>
         <source>&amp;Fit</source>
         <translation>&amp;Підігнати</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="309"/>
+        <location filename="../../mainwindow.ui" line="313"/>
         <source>&amp;Rotate Clockwise</source>
         <translation>&amp;Обернути за год. стрілкою</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="319"/>
+        <location filename="../../mainwindow.ui" line="323"/>
         <source>Rotate &amp;Counterclockwise</source>
         <translation>Обернути проти &amp;год. стрілки</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="324"/>
+        <location filename="../../mainwindow.ui" line="328"/>
         <source>P&amp;references</source>
         <translation>На&amp;лаштування</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="329"/>
+        <location filename="../../mainwindow.ui" line="333"/>
         <source>&amp;Print</source>
         <translation>&amp;Друк</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="332"/>
+        <location filename="../../mainwindow.ui" line="336"/>
         <source>Ctrl+P</source>
         <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="342"/>
+        <location filename="../../mainwindow.ui" line="346"/>
         <source>First File</source>
         <translation>Перший файл</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="345"/>
+        <location filename="../../mainwindow.ui" line="349"/>
         <source>Home</source>
         <translation>Home</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="355"/>
+        <location filename="../../mainwindow.ui" line="359"/>
         <source>Last File</source>
         <translation>Останній файл</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="358"/>
+        <location filename="../../mainwindow.ui" line="362"/>
         <source>End</source>
         <translation>End</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="368"/>
+        <location filename="../../mainwindow.ui" line="372"/>
         <source>&amp;New Window</source>
         <translation>&amp;Нове вікно</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="371"/>
+        <location filename="../../mainwindow.ui" line="375"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="376"/>
+        <location filename="../../mainwindow.ui" line="380"/>
         <source>Flip &amp;Horizontally</source>
         <translation>Віддзеркалити &amp;горизонтально</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="386"/>
+        <location filename="../../mainwindow.ui" line="390"/>
         <source>Capture Screenshot</source>
         <translation>Зробити знімок екрана</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="394"/>
+        <location filename="../../mainwindow.ui" line="398"/>
         <source>F&amp;ull Screen</source>
         <translation>П&amp;овний екран</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="397"/>
+        <location filename="../../mainwindow.ui" line="401"/>
         <source>F11</source>
         <translation>F11</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="402"/>
+        <location filename="../../mainwindow.ui" line="406"/>
         <source>Flip &amp;Vertically</source>
         <translation>Віддзеркалити &amp;вертикально</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="412"/>
+        <location filename="../../mainwindow.ui" line="416"/>
         <source>&amp;Paste from Clipboard</source>
         <translation>&amp;Вставити з буфера обміну</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="425"/>
+        <location filename="../../mainwindow.ui" line="429"/>
         <source>&amp;Slide Show</source>
         <translation>&amp;Показ слайдів</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="435"/>
+        <location filename="../../mainwindow.ui" line="439"/>
         <source>&amp;Delete</source>
         <translation>В&amp;илучити</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="438"/>
+        <location filename="../../mainwindow.ui" line="442"/>
         <source>Del</source>
         <translation>Del</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="446"/>
+        <location filename="../../mainwindow.ui" line="450"/>
         <source>Show Thumbnails</source>
         <translation>Показати значки</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="451"/>
+        <location filename="../../mainwindow.ui" line="455"/>
         <source>File Properties</source>
         <translation>Властивості файлу</translation>
     </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="463"/>
+        <source>Open &amp;Directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="466"/>
+        <source>Ctrl+D</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../mainwindow.ui" line="55"/>
         <source>&amp;File</source>
         <translation>&amp;Файл</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="71"/>
+        <location filename="../../mainwindow.ui" line="72"/>
         <source>&amp;Help</source>
         <translation>&amp;Довідка</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="77"/>
+        <location filename="../../mainwindow.ui" line="78"/>
         <source>Go</source>
         <translation>Перейти</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="86"/>
+        <location filename="../../mainwindow.ui" line="87"/>
         <source>&amp;View</source>
         <translation>П&amp;ерегляд</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="100"/>
+        <location filename="../../mainwindow.ui" line="101"/>
         <source>&amp;Edit</source>
         <translation>&amp;Редагування</translation>
     </message>
     <message>
-        <location filename="../../mainwindow.ui" line="120"/>
+        <location filename="../../mainwindow.ui" line="121"/>
         <source>Toolbar</source>
         <translation>Панель інструментів</translation>
     </message>
@@ -392,15 +416,15 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
     </message>
     <message>
         <source>TODO: Add configuration options here</source>
-        <translation>На майбутнє: Додати тут опції налаштування</translation>
+        <translation type="vanished">На майбутнє: Додати тут опції налаштування</translation>
     </message>
     <message>
         <source>Tab 1</source>
-        <translation>Вкладка 1</translation>
+        <translation type="vanished">Вкладка 1</translation>
     </message>
     <message>
         <source>Tab 2</source>
-        <translation>Вкладка 2</translation>
+        <translation type="vanished">Вкладка 2</translation>
     </message>
 </context>
 <context>
@@ -411,42 +435,47 @@ Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
         <translation>Знімок екрану</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="28"/>
+        <location filename="../../screenshotdialog.ui" line="27"/>
         <source>Take a screenshot</source>
         <translation>Зробити знімок</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="35"/>
+        <location filename="../../screenshotdialog.ui" line="34"/>
         <source>Region</source>
         <translation>Регіон</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="41"/>
+        <location filename="../../screenshotdialog.ui" line="40"/>
         <source>Whole screen</source>
         <translation>Екран цілком</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="51"/>
+        <location filename="../../screenshotdialog.ui" line="50"/>
         <source>Current window only</source>
         <translation>Лише поточне вікно</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="61"/>
+        <location filename="../../screenshotdialog.ui" line="57"/>
+        <source>Capture an area of the screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../screenshotdialog.ui" line="67"/>
         <source>Include mouse cursor</source>
         <translation>Включаючи вказівник миші</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="68"/>
+        <location filename="../../screenshotdialog.ui" line="74"/>
         <source> seconds</source>
         <translation> секунд</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="85"/>
+        <location filename="../../screenshotdialog.ui" line="91"/>
         <source>Delay:</source>
         <translation>Затримка:</translation>
     </message>
     <message>
-        <location filename="../../screenshotdialog.ui" line="95"/>
+        <location filename="../../screenshotdialog.ui" line="101"/>
         <source>Include window title and frame</source>
         <translation>Включаючи заголовок вікна та кадр</translation>
     </message>
