@@ -137,6 +137,16 @@
         <source>Icons Theme</source>
         <translation>Ikontema</translation>
     </message>
+    <message>
+        <location filename="../../../iconthemeconfig.ui" line="87"/>
+        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
+        <translation>KDE-udvidelsen af XDG-ikontemaer -&gt; FollowsColorScheme</translation>
+    </message>
+    <message>
+        <location filename="../../../iconthemeconfig.ui" line="90"/>
+        <source>Colorize icons based on widget style (palette)</source>
+        <translation>Farvelagte ikoner baseret på widget-stil (palet)</translation>
+    </message>
 </context>
 <context>
     <name>LXQtThemeConfig</name>
@@ -145,36 +155,41 @@
         <source>LXQt Theme</source>
         <translation>LXQt-tema</translation>
     </message>
+    <message>
+        <location filename="../../../lxqtthemeconfig.ui" line="57"/>
+        <source>Override user-defined wallpaper</source>
+        <translation>Tilsidesæt brugerdefineret tapet</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../../main.cpp" line="44"/>
+        <location filename="../../../main.cpp" line="57"/>
         <source>LXQt Appearance Configuration</source>
         <translation>Konfiguraton af LXQt udseende</translation>
     </message>
     <message>
-        <location filename="../../../main.cpp" line="50"/>
+        <location filename="../../../main.cpp" line="63"/>
         <source>Widget Style</source>
         <translation>Widget-stil</translation>
     </message>
     <message>
-        <location filename="../../../main.cpp" line="54"/>
+        <location filename="../../../main.cpp" line="67"/>
         <source>Icons Theme</source>
         <translation>Ikontema</translation>
     </message>
     <message>
-        <location filename="../../../main.cpp" line="58"/>
+        <location filename="../../../main.cpp" line="71"/>
         <source>LXQt Theme</source>
         <translation>LXQt-tema</translation>
     </message>
     <message>
-        <location filename="../../../main.cpp" line="62"/>
+        <location filename="../../../main.cpp" line="75"/>
         <source>Font</source>
         <translation>Skrifttype</translation>
     </message>
     <message>
-        <location filename="../../../main.cpp" line="67"/>
+        <location filename="../../../main.cpp" line="80"/>
         <source>Cursor</source>
         <translation>Markør</translation>
     </message>
