@@ -13,13 +13,27 @@
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Use arrow keys to change settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ajusts de retroil·luminació i brillantor:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Utilitzeu les tecles de les fletxes per canviar els ajusts.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
+    <message>
+        <location filename="../../../brightnesssettings.ui" line="35"/>
+        <source>Require confirmation after settings change</source>
+        <translation>Requereix la confirmació després de canviar els ajusts</translation>
+    </message>
+    <message>
+        <location filename="../../../brightnesssettings.cpp" line="68"/>
+        <source>Brightness settings changed</source>
+        <translation>S&apos;han canviat els ajusts de la brillantor</translation>
+    </message>
+    <message>
+        <location filename="../../../brightnesssettings.cpp" line="69"/>
+        <source>Confirmation required. Are the settings correct?</source>
+        <translation>Cal confirmar. Són correctes els ajusts?</translation>
+    </message>
 </context>
 <context>
     <name>OutputWidget</name>
     <message>
-        <location filename="../../../outputwidget.ui" line="20"/>
         <source>Form</source>
-        <translation>Formulari</translation>
+        <translation type="vanished">Formulari</translation>
     </message>
     <message>
         <location filename="../../../outputwidget.ui" line="38"/>
