@@ -13,14 +13,24 @@
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Use arrow keys to change settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Indstillinger for backlight og lysstyrke:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Brug piletasterne for at ændre indstillingerne.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
+    <message>
+        <location filename="../../../brightnesssettings.ui" line="35"/>
+        <source>Require confirmation after settings change</source>
+        <translation>Kræv bekræftelse efter indstillinger er blevet ændret</translation>
+    </message>
+    <message>
+        <location filename="../../../brightnesssettings.cpp" line="68"/>
+        <source>Brightness settings changed</source>
+        <translation>Lysstyrkeindstillinger ændret</translation>
+    </message>
+    <message>
+        <location filename="../../../brightnesssettings.cpp" line="69"/>
+        <source>Confirmation required. Are the settings correct?</source>
+        <translation>Bekræftelse krævet. Er indstillingerne korrekte?</translation>
+    </message>
 </context>
 <context>
     <name>OutputWidget</name>
-    <message>
-        <location filename="../../../outputwidget.ui" line="20"/>
-        <source>Form</source>
-        <translation>Formular</translation>
-    </message>
     <message>
         <location filename="../../../outputwidget.ui" line="38"/>
         <source>&lt;b&gt;Output:&lt;/b&gt;</source>
