@@ -1,90 +1,98 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="tr">
+<context>
+    <name>LXQtTaskBar</name>
+    <message>
+        <location filename="../../../lxqttaskbar.cpp" line="641"/>
+        <source>Activate task %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LXQtTaskButton</name>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="477"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="478"/>
         <source>Application</source>
         <translation>Uygulama</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="511"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="512"/>
         <source>To &amp;Desktop</source>
         <translation>&amp;Masaüstüne</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="513"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
         <source>&amp;All Desktops</source>
         <translation>&amp;Tüm Masaüstlerine</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="521"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="522"/>
         <source>Desktop &amp;%1</source>
         <translation>Masaüstü &amp;%1</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="528"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="529"/>
         <source>&amp;To Current Desktop</source>
         <translation>&amp;Şimdiki Masaüstüne</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="537"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="538"/>
         <source>Ma&amp;ximize</source>
         <translation>Bü&amp;yüt</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="544"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="545"/>
         <source>Maximize vertically</source>
         <translation>Dikey büyüt</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="549"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
         <source>Maximize horizontally</source>
         <translation>Yatay büyüt</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="555"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="556"/>
         <source>&amp;Restore</source>
         <translation>&amp;Geri Yükle</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="559"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="560"/>
         <source>Mi&amp;nimize</source>
         <translation>Kü&amp;çült</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="566"/>
         <source>Roll down</source>
         <translation>Aşağı indir</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="571"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="572"/>
         <source>Roll up</source>
         <translation>Yukarı çıkar</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="579"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="580"/>
         <source>&amp;Layer</source>
         <translation>&amp;Katman</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="581"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="582"/>
         <source>Always on &amp;top</source>
         <translation>Her zaman &amp;üstte</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="587"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="588"/>
         <source>&amp;Normal</source>
         <translation>&amp;Normal</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="593"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="594"/>
         <source>Always on &amp;bottom</source>
         <translation>Her zaman &amp;altta</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
+        <location filename="../../../lxqttaskbutton.cpp" line="602"/>
         <source>&amp;Close</source>
         <translation>&amp;Kapat</translation>
     </message>
@@ -123,58 +131,67 @@
         <translation>Genel</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="34"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="43"/>
         <source>Show only windows from desktop</source>
         <translation>Sadece masaüstünden pencereleri göster</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="46"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="55"/>
         <source>Show only windows from &amp;panel&apos;s screen</source>
         <translation>Sadece &amp;panel ekranından pencereleri göster</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="53"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="62"/>
         <source>Show only minimized windows</source>
         <translation>Sadece simge durumuna küçültülmüş pencereleri göster</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="60"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="69"/>
         <source>Raise minimized windows on current desktop</source>
         <translation>Geçerli masaüstündeki pencereleri aç</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="77"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="83"/>
+        <source>Cycle windows on wheel scrolling</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="93"/>
         <source>Window &amp;grouping</source>
         <translation>Pencereleri &amp;grupla</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="86"/>
-        <source>Show popup on mouse hover </source>
-        <translation>Fare imleci üzerine geldiğinde göster</translation>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="102"/>
+        <source>Show popup on mouse hover</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="96"/>
+        <source>Show popup on mouse hover </source>
+        <translation type="vanished">Fare imleci üzerine geldiğinde göster</translation>
+    </message>
+    <message>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="112"/>
         <source>Appearance</source>
         <translation>Görünüm</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="115"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="131"/>
         <source>Maximum button width</source>
         <translation>Maksimum düğme genişliği</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="128"/>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="154"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="144"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="170"/>
         <source> px</source>
-        <translation type="unfinished"></translation>
+        <translation> px</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="141"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="157"/>
         <source>Maximum button height</source>
         <translation>Maksimum düğme yüksekliği</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="174"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="190"/>
         <source>Use icons by WindowClass, if available</source>
         <translation>Mümkün ise pencere tarafından sağlanan simgeyi kullan</translation>
     </message>
@@ -187,7 +204,7 @@
         <translation type="vanished">Tüm masaüstlerindeki pencereleri göster</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="167"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="183"/>
         <source>Auto&amp;rotate buttons when the panel is vertical</source>
         <translation>Panel dikey olduğunda düğmeleri otomatik &amp;döndür</translation>
     </message>
@@ -196,7 +213,7 @@
         <translation type="vanished">Pencere Listesi Görünümü</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="105"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="121"/>
         <source>Button style</source>
         <translation>Düğme biçimi</translation>
     </message>
@@ -205,7 +222,7 @@
         <translation type="vanished">En fazla düğme genişliği</translation>
     </message>
     <message>
-        <location filename="../../../lxqttaskbarconfiguration.ui" line="67"/>
+        <location filename="../../../lxqttaskbarconfiguration.ui" line="76"/>
         <source>Close on middle-click</source>
         <translation>Orta tıklama ile kapat</translation>
     </message>
