@@ -24,7 +24,32 @@
         <translation>Vis på:</translation>
     </message>
     <message>
-        <location filename="../../configuredialog/configuredialog.ui" line="56"/>
+        <location filename="../../configuredialog/configuredialog.ui" line="46"/>
+        <source>Show history first</source>
+        <translation>Vis historik først</translation>
+    </message>
+    <message>
+        <location filename="../../configuredialog/configuredialog.ui" line="53"/>
+        <source>Store/show history</source>
+        <translation>Gem/vis historik</translation>
+    </message>
+    <message>
+        <location filename="../../configuredialog/configuredialog.ui" line="60"/>
+        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
+        <translation>&lt;b&gt;Bemærk&lt;/b&gt;: Størrelsen af top-niveau widgets er begrænset til 2/3 af skrivebordets højde og bredde.</translation>
+    </message>
+    <message>
+        <location filename="../../configuredialog/configuredialog.ui" line="63"/>
+        <source>Show list with:</source>
+        <translation>Vis liste med:</translation>
+    </message>
+    <message>
+        <location filename="../../configuredialog/configuredialog.ui" line="70"/>
+        <source> item(s)</source>
+        <translation> post(er)</translation>
+    </message>
+    <message>
+        <location filename="../../configuredialog/configuredialog.ui" line="90"/>
         <source>Shortcut:</source>
         <translation>Genvej:</translation>
     </message>
@@ -62,17 +87,17 @@
         <translation>Programstarter </translation>
     </message>
     <message>
-        <location filename="../../dialog.cpp" line="93"/>
+        <location filename="../../dialog.cpp" line="94"/>
         <source>Configure</source>
         <translation>Konfigurér</translation>
     </message>
     <message>
-        <location filename="../../dialog.cpp" line="97"/>
+        <location filename="../../dialog.cpp" line="98"/>
         <source>Clear History</source>
         <translation>Ryd historik</translation>
     </message>
     <message>
-        <location filename="../../dialog.cpp" line="349"/>
+        <location filename="../../dialog.cpp" line="351"/>
         <source>Show/hide runner dialog</source>
         <translation>Vis/skjul runner-dialog</translation>
     </message>
@@ -85,7 +110,7 @@
         <translation>Historik</translation>
     </message>
     <message>
-        <location filename="../../providers.cpp" line="801"/>
+        <location filename="../../providers.cpp" line="822"/>
         <source>Mathematics</source>
         <translation>Matematik</translation>
     </message>
