@@ -17,88 +17,88 @@
 <context>
     <name>MainDialog</name>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1012"/>
+        <location filename="../../ui_obconf.h" line="1012"/>
         <source>Window Manager Preferences</source>
         <translation>Pencere Yönetici Tercihleri</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1017"/>
+        <location filename="../../ui_obconf.h" line="1017"/>
         <source>Theme</source>
         <translation>Tema</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1019"/>
+        <location filename="../../ui_obconf.h" line="1019"/>
         <source>Appearance</source>
         <translation>Görünüm</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1021"/>
+        <location filename="../../ui_obconf.h" line="1021"/>
         <source>Font</source>
         <translation>Yazıtipi</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1023"/>
-        <location filename="../../../build/src/ui_obconf.h" line="1038"/>
+        <location filename="../../ui_obconf.h" line="1023"/>
+        <location filename="../../ui_obconf.h" line="1038"/>
         <source>Windows</source>
         <translation>Pencereler</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1025"/>
+        <location filename="../../ui_obconf.h" line="1025"/>
         <source>Move &amp; Resize</source>
         <translation>Taşı ve Boyutlandır</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1027"/>
+        <location filename="../../ui_obconf.h" line="1027"/>
         <source>Mouse</source>
         <translation>Fare</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1029"/>
+        <location filename="../../ui_obconf.h" line="1029"/>
         <source>Desktops</source>
         <translation>Masaüstü</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1031"/>
+        <location filename="../../ui_obconf.h" line="1031"/>
         <source>Margins</source>
         <translation>Kenarlar</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1033"/>
+        <location filename="../../ui_obconf.h" line="1033"/>
         <source>Dock</source>
-        <translation type="unfinished"></translation>
+        <translation>Rıhtım</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1036"/>
+        <location filename="../../ui_obconf.h" line="1036"/>
         <source>&amp;Install a new theme...</source>
         <translation>Yeni bir tema &amp;yükle...</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1037"/>
+        <location filename="../../ui_obconf.h" line="1037"/>
         <source>Create a theme &amp;archive (.obt)...</source>
         <translation>Bir tema &amp;arşivi (.obt) oluştur...</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1039"/>
+        <location filename="../../ui_obconf.h" line="1039"/>
         <source>&amp;Windows retain a border when undecorated</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Pencereler süslemesiz bir sınıra sahip</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1040"/>
+        <location filename="../../ui_obconf.h" line="1040"/>
         <source>A&amp;nimate iconify and restore</source>
-        <translation type="unfinished"></translation>
+        <translation>S&amp;imgelendirme ve geri yükleme canlandır</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1041"/>
+        <location filename="../../ui_obconf.h" line="1041"/>
         <source>Window Titles</source>
-        <translation type="unfinished"></translation>
+        <translation>Pencere Başlıkları</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1042"/>
+        <location filename="../../ui_obconf.h" line="1042"/>
         <source>Button order:</source>
-        <translation type="unfinished"></translation>
+        <translation>Düğme sırası:</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1043"/>
+        <location filename="../../ui_obconf.h" line="1043"/>
         <source>N: Window icon
 L: Window label (Title)
 I: Iconify (Minimize)
@@ -106,474 +106,480 @@ M: Maximize
 C: Close
 S: Shade (Roll up)
 D: Omnipresent (On all desktops)</source>
-        <translation type="unfinished"></translation>
+        <translation>N: Pencere Simgesi
+L: Pencere etiketi (Başlık)
+I: Simge durumu (Küçült)
+M: Büyüt
+C: Kapat
+S: Gölge (Hareket)
+D: Hazır (Tüm masaüstlerinde)</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1056"/>
+        <location filename="../../ui_obconf.h" line="1056"/>
         <source>&amp;Active window title: </source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Etkin pencere başlığı: </translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1057"/>
+        <location filename="../../ui_obconf.h" line="1057"/>
         <source>&amp;Inactive window title: </source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Pasif pencere başlığı: </translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1058"/>
+        <location filename="../../ui_obconf.h" line="1058"/>
         <source>Menu &amp;header: </source>
-        <translation type="unfinished"></translation>
+        <translation>Menü &amp;başığı: </translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1059"/>
+        <location filename="../../ui_obconf.h" line="1059"/>
         <source>&amp;Menu Item: </source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Menü Ögesi: </translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1060"/>
+        <location filename="../../ui_obconf.h" line="1060"/>
         <source>Active &amp;On-screen display: </source>
-        <translation type="unfinished"></translation>
+        <translation>Etkin &amp;Görünen ekranda: </translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1061"/>
+        <location filename="../../ui_obconf.h" line="1061"/>
         <source>Inactive O&amp;n-screen display: </source>
-        <translation type="unfinished"></translation>
+        <translation>Pasif G&amp;örünen ekranda: </translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1062"/>
+        <location filename="../../ui_obconf.h" line="1062"/>
         <source>Focus &amp;new windows when they appear</source>
-        <translation type="unfinished"></translation>
+        <translation>Yeni &amp;pencereleri göründükleri zaman odakla</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1063"/>
+        <location filename="../../ui_obconf.h" line="1063"/>
         <source>&amp;Place new windows under the mouse pointer</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Fare işaretçisinin altına yeni pencereler yerleştirin</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1064"/>
+        <location filename="../../ui_obconf.h" line="1064"/>
         <source>&amp;Center new windows when they are placed</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Yerleştirildiğinde yeni pencereleri ortala</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1065"/>
+        <location filename="../../ui_obconf.h" line="1065"/>
         <source>Prefer to place new windows &amp;on:</source>
-        <translation type="unfinished"></translation>
+        <translation>Yeni pencere yerleştirme &amp;tercihi:</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1068"/>
+        <location filename="../../ui_obconf.h" line="1068"/>
         <source>All monitors</source>
-        <translation type="unfinished"></translation>
+        <translation>Tüm ekranlar</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1069"/>
+        <location filename="../../ui_obconf.h" line="1069"/>
         <source>The active monitor</source>
-        <translation type="unfinished"></translation>
+        <translation>Etkin ekran</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1070"/>
+        <location filename="../../ui_obconf.h" line="1070"/>
         <source>The monitor with the mouse</source>
-        <translation type="unfinished"></translation>
+        <translation>Fareyle ekran</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1071"/>
+        <location filename="../../ui_obconf.h" line="1071"/>
         <source>Primary monitor</source>
-        <translation type="unfinished"></translation>
+        <translation>Birincil ekran</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1073"/>
+        <location filename="../../ui_obconf.h" line="1073"/>
         <source>Primary Monitor</source>
-        <translation type="unfinished"></translation>
+        <translation>Birincil ekran</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1074"/>
+        <location filename="../../ui_obconf.h" line="1074"/>
         <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
-        <translation type="unfinished"></translation>
+        <translation>Birincil monitör, Openbox&apos;un pencere diyalogları koyacağı yer.</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1075"/>
+        <location filename="../../ui_obconf.h" line="1075"/>
         <source>Primary &amp;monitor:</source>
-        <translation type="unfinished"></translation>
+        <translation>Birincil &amp;ekran</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1078"/>
+        <location filename="../../ui_obconf.h" line="1078"/>
         <source>Fixed Monitor</source>
-        <translation type="unfinished"></translation>
+        <translation>Sabit Ekran</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1079"/>
+        <location filename="../../ui_obconf.h" line="1079"/>
         <source>Active Monitor</source>
-        <translation type="unfinished"></translation>
+        <translation>Etkin Ekran</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1080"/>
+        <location filename="../../ui_obconf.h" line="1080"/>
         <source>Monitor With Mouse Pointer</source>
-        <translation type="unfinished"></translation>
+        <translation>Ekranı Fareyle İzle</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1082"/>
+        <location filename="../../ui_obconf.h" line="1082"/>
         <source>&amp;Fixed monitor:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1083"/>
+        <location filename="../../ui_obconf.h" line="1083"/>
         <source>Moving and Resizing Windows</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1084"/>
+        <location filename="../../ui_obconf.h" line="1084"/>
         <source>Update the window contents while &amp;resizing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1085"/>
+        <location filename="../../ui_obconf.h" line="1085"/>
         <source>Drag &amp;threshold distance:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1086"/>
+        <location filename="../../ui_obconf.h" line="1086"/>
         <source>Amount of resistance against other &amp;windows:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1087"/>
+        <location filename="../../ui_obconf.h" line="1087"/>
         <source>Amount of resistance against screen &amp;edges:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1088"/>
+        <location filename="../../ui_obconf.h" line="1088"/>
         <source>&amp;Amount of time to wait before switching:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1089"/>
+        <location filename="../../ui_obconf.h" line="1089"/>
         <source>&amp;Switch desktops when moving a window past the screen edge</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1090"/>
+        <location filename="../../ui_obconf.h" line="1090"/>
         <source>Information Dialog</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1093"/>
-        <location filename="../../../build/src/ui_obconf.h" line="1100"/>
+        <location filename="../../ui_obconf.h" line="1093"/>
+        <location filename="../../ui_obconf.h" line="1100"/>
         <source>Centered</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1094"/>
+        <location filename="../../ui_obconf.h" line="1094"/>
         <source>From left edge</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1095"/>
+        <location filename="../../ui_obconf.h" line="1095"/>
         <source>From right edge</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1097"/>
+        <location filename="../../ui_obconf.h" line="1097"/>
         <source>Fixed &amp;y position:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1101"/>
+        <location filename="../../ui_obconf.h" line="1101"/>
         <source>From top edge</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1102"/>
+        <location filename="../../ui_obconf.h" line="1102"/>
         <source>From bottom edge</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1104"/>
+        <location filename="../../ui_obconf.h" line="1104"/>
         <source>Information dialog&apos;s &amp;position:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1105"/>
+        <location filename="../../ui_obconf.h" line="1105"/>
         <source>Fixed &amp;x position:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1106"/>
+        <location filename="../../ui_obconf.h" line="1106"/>
         <source>Show &amp;information dialog:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1109"/>
+        <location filename="../../ui_obconf.h" line="1109"/>
         <source>When resizing terminal windows</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1110"/>
+        <location filename="../../ui_obconf.h" line="1110"/>
         <source>Always</source>
         <translation>Her Zaman</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1111"/>
+        <location filename="../../ui_obconf.h" line="1111"/>
         <source>Never</source>
         <translation>Hiçbir Zaman</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1115"/>
+        <location filename="../../ui_obconf.h" line="1115"/>
         <source>Centered on the window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1116"/>
+        <location filename="../../ui_obconf.h" line="1116"/>
         <source>Above the window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1117"/>
+        <location filename="../../ui_obconf.h" line="1117"/>
         <source>Fixed position on screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1119"/>
+        <location filename="../../ui_obconf.h" line="1119"/>
         <source>Focusing Windows</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1120"/>
+        <location filename="../../ui_obconf.h" line="1120"/>
         <source>Focus windows when the mouse pointer moves over them</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1121"/>
+        <location filename="../../ui_obconf.h" line="1121"/>
         <source>&amp;Delay before focusing and raising windows:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1122"/>
+        <location filename="../../ui_obconf.h" line="1122"/>
         <source>Move focus under the mouse when &amp;switching desktops</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1123"/>
+        <location filename="../../ui_obconf.h" line="1123"/>
         <source>Move focus &amp;under the mouse when the mouse is not moving</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1124"/>
+        <location filename="../../ui_obconf.h" line="1124"/>
         <source>&amp;Raise windows when the mouse pointer moves over them</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1125"/>
+        <location filename="../../ui_obconf.h" line="1125"/>
         <source>Titlebar</source>
         <translation>Başlık Çubuğu</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1126"/>
+        <location filename="../../ui_obconf.h" line="1126"/>
         <source>Double click on the &amp;titlebar:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1129"/>
+        <location filename="../../ui_obconf.h" line="1129"/>
         <source>Maximizes the window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1130"/>
+        <location filename="../../ui_obconf.h" line="1130"/>
         <source>Shades the window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1132"/>
+        <location filename="../../ui_obconf.h" line="1132"/>
         <source>Double click ti&amp;me:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1133"/>
+        <location filename="../../ui_obconf.h" line="1133"/>
         <source>&amp;Show a notification when switching desktops</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1134"/>
+        <location filename="../../ui_obconf.h" line="1134"/>
         <source>&amp;Amount of time to show the notification for:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1135"/>
+        <location filename="../../ui_obconf.h" line="1135"/>
         <source>&amp;Number of desktops: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1136"/>
+        <location filename="../../ui_obconf.h" line="1136"/>
         <source>&amp;Desktop names:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1137"/>
+        <location filename="../../ui_obconf.h" line="1137"/>
         <source>Desktop Margins</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1138"/>
+        <location filename="../../ui_obconf.h" line="1138"/>
         <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1139"/>
+        <location filename="../../ui_obconf.h" line="1139"/>
         <source>Left:</source>
         <translation type="unfinished">Sol:</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1140"/>
-        <location filename="../../../build/src/ui_obconf.h" line="1142"/>
-        <location filename="../../../build/src/ui_obconf.h" line="1144"/>
-        <location filename="../../../build/src/ui_obconf.h" line="1146"/>
+        <location filename="../../ui_obconf.h" line="1140"/>
+        <location filename="../../ui_obconf.h" line="1142"/>
+        <location filename="../../ui_obconf.h" line="1144"/>
+        <location filename="../../ui_obconf.h" line="1146"/>
         <source>px</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1141"/>
+        <location filename="../../ui_obconf.h" line="1141"/>
         <source>Top:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1143"/>
+        <location filename="../../ui_obconf.h" line="1143"/>
         <source>Right:</source>
         <translation>Sağ:</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1145"/>
+        <location filename="../../ui_obconf.h" line="1145"/>
         <source>Bottom:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1147"/>
+        <location filename="../../ui_obconf.h" line="1147"/>
         <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1148"/>
+        <location filename="../../ui_obconf.h" line="1148"/>
         <source>Position</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1149"/>
+        <location filename="../../ui_obconf.h" line="1149"/>
         <source>&amp;Position:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1152"/>
+        <location filename="../../ui_obconf.h" line="1152"/>
         <source>Top Left</source>
         <translation>Sol Üst</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1153"/>
+        <location filename="../../ui_obconf.h" line="1153"/>
         <source>Top</source>
         <translation>Üst</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1154"/>
+        <location filename="../../ui_obconf.h" line="1154"/>
         <source>Top Right</source>
         <translation>Sağ Üst</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1155"/>
+        <location filename="../../ui_obconf.h" line="1155"/>
         <source>Left</source>
         <translation>Sol</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1156"/>
+        <location filename="../../ui_obconf.h" line="1156"/>
         <source>Right</source>
         <translation>Sağ</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1157"/>
+        <location filename="../../ui_obconf.h" line="1157"/>
         <source>Bottom Left</source>
         <translation>Sol Alt</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1158"/>
+        <location filename="../../ui_obconf.h" line="1158"/>
         <source>Bottom</source>
         <translation>Alt</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1159"/>
+        <location filename="../../ui_obconf.h" line="1159"/>
         <source>Bottom Right</source>
         <translation>Sağ Alt</translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1160"/>
+        <location filename="../../ui_obconf.h" line="1160"/>
         <source>Floating</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1162"/>
+        <location filename="../../ui_obconf.h" line="1162"/>
         <source>&amp;Floating position:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1163"/>
+        <location filename="../../ui_obconf.h" line="1163"/>
         <source>x</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1164"/>
+        <location filename="../../ui_obconf.h" line="1164"/>
         <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1165"/>
+        <location filename="../../ui_obconf.h" line="1165"/>
         <source>&amp;Orientation: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1168"/>
+        <location filename="../../ui_obconf.h" line="1168"/>
         <source>Vertical</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1169"/>
+        <location filename="../../ui_obconf.h" line="1169"/>
         <source>Horizontal</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1171"/>
+        <location filename="../../ui_obconf.h" line="1171"/>
         <source>Stacking</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1172"/>
+        <location filename="../../ui_obconf.h" line="1172"/>
         <source>Keep dock &amp;above other windows</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1173"/>
+        <location filename="../../ui_obconf.h" line="1173"/>
         <source>A&amp;llow dock to be both above and below windows</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1174"/>
+        <location filename="../../ui_obconf.h" line="1174"/>
         <source>Keep dock &amp;below other windows</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1175"/>
+        <location filename="../../ui_obconf.h" line="1175"/>
         <source>Hiding</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1176"/>
+        <location filename="../../ui_obconf.h" line="1176"/>
         <source>&amp;Delay before hiding:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1177"/>
+        <location filename="../../ui_obconf.h" line="1177"/>
         <source>Delay before &amp;showing:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1178"/>
+        <location filename="../../ui_obconf.h" line="1178"/>
         <source>&amp;Hide off screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../../build/src/ui_obconf.h" line="1179"/>
+        <location filename="../../ui_obconf.h" line="1179"/>
         <source>About</source>
         <translation>Hakkında</translation>
     </message>
@@ -718,18 +724,18 @@ Options:
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../obconf-qt.cpp" line="221"/>
-        <location filename="../../obconf-qt.cpp" line="237"/>
+        <location filename="../../obconf-qt.cpp" line="225"/>
+        <location filename="../../obconf-qt.cpp" line="241"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../obconf-qt.cpp" line="222"/>
+        <location filename="../../obconf-qt.cpp" line="226"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../obconf-qt.cpp" line="235"/>
+        <location filename="../../obconf-qt.cpp" line="239"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
