@@ -4,60 +4,57 @@
 <context>
     <name>CardWidget</name>
     <message>
-        <location filename="../cardwidget.ui" line="14"/>
+        <location filename="../../cardwidget.ui" line="14"/>
         <source>Form</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../cardwidget.ui" line="29"/>
+        <location filename="../../cardwidget.ui" line="29"/>
         <source>Card Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../cardwidget.ui" line="38"/>
+        <location filename="../../cardwidget.ui" line="38"/>
         <source>Profile:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../cardwidget.cc" line="66"/>
+        <location filename="../../cardwidget.cc" line="66"/>
         <source>pa_context_set_card_profile_by_index() failed</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>ChannelWidget</name>
+    <name>Channel</name>
     <message>
-        <location filename="../channelwidget.ui" line="14"/>
-        <source>Form</source>
+        <location filename="../../channel.cc" line="89"/>
+        <source>%1% (%2dB)</source>
+        <comment>volume slider label [X% (YdB)]</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../channelwidget.ui" line="20"/>
-        <source>&lt;b&gt;left-front&lt;/b&gt;</source>
+        <location filename="../../channel.cc" line="93"/>
+        <source>%1%</source>
+        <comment>volume slider label [X%]</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../channelwidget.ui" line="34"/>
-        <source>&lt;small&gt;50%&lt;/small&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../channelwidget.cc" line="96"/>
+        <location filename="../../channel.cc" line="160"/>
         <source>&lt;small&gt;Silence&lt;/small&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../channelwidget.cc" line="96"/>
+        <location filename="../../channel.cc" line="160"/>
         <source>&lt;small&gt;Min&lt;/small&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../channelwidget.cc" line="98"/>
+        <location filename="../../channel.cc" line="162"/>
         <source>&lt;small&gt;100% (0dB)&lt;/small&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../channelwidget.cc" line="101"/>
+        <location filename="../../channel.cc" line="165"/>
         <source>&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</source>
         <translation type="unfinished"></translation>
     </message>
@@ -65,298 +62,293 @@
 <context>
     <name>DeviceWidget</name>
     <message>
-        <location filename="../devicewidget.ui" line="14"/>
+        <location filename="../../devicewidget.ui" line="14"/>
         <source>Form</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.ui" line="22"/>
-        <source>icon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../devicewidget.ui" line="36"/>
+        <location filename="../../devicewidget.ui" line="36"/>
         <source>Device Title</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.ui" line="58"/>
-        <source>lock</source>
+        <location filename="../../devicewidget.ui" line="56"/>
+        <source>Mute audio</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.ui" line="88"/>
+        <location filename="../../devicewidget.ui" line="69"/>
+        <source>Lock channels together</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../devicewidget.ui" line="85"/>
+        <source>Set as fallback</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../devicewidget.ui" line="103"/>
         <source>&lt;b&gt;Port:&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.ui" line="104"/>
+        <location filename="../../devicewidget.ui" line="126"/>
         <source>Show advanced options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.ui" line="117"/>
+        <location filename="../../devicewidget.ui" line="172"/>
         <source>PCM</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.ui" line="124"/>
+        <location filename="../../devicewidget.ui" line="182"/>
         <source>AC3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.ui" line="131"/>
+        <location filename="../../devicewidget.ui" line="189"/>
         <source>EAC3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.ui" line="138"/>
+        <location filename="../../devicewidget.ui" line="196"/>
         <source>DTS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.ui" line="145"/>
+        <location filename="../../devicewidget.ui" line="203"/>
         <source>MPEG</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.ui" line="152"/>
+        <location filename="../../devicewidget.ui" line="210"/>
         <source>AAC</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.ui" line="165"/>
+        <location filename="../../devicewidget.ui" line="238"/>
         <source>&lt;b&gt;Latency offset:&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.ui" line="172"/>
+        <location filename="../../devicewidget.ui" line="245"/>
         <source> ms</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.cc" line="53"/>
-        <source>Rename Device...</source>
+        <location filename="../../devicewidget.cc" line="40"/>
+        <source>Rename device...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.cc" line="155"/>
+        <location filename="../../devicewidget.cc" line="154"/>
         <source>pa_context_set_port_latency_offset() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.cc" line="241"/>
+        <location filename="../../devicewidget.cc" line="225"/>
         <source>Sorry, but device renaming is not supported.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.cc" line="246"/>
+        <location filename="../../devicewidget.cc" line="226"/>
         <source>You need to load module-device-manager in the PulseAudio server in order to rename devices</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../devicewidget.cc" line="267"/>
-        <source>pa_ext_device_manager_write() failed</source>
+        <location filename="../../devicewidget.cc" line="232"/>
+        <source>Rename device %1 to:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../devicewidget.cc" line="239"/>
+        <source>pa_ext_device_manager_set_device_description() failed</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="14"/>
+        <location filename="../../mainwindow.ui" line="14"/>
         <source>Volume Control</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="29"/>
-        <source>_Playback</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="50"/>
+        <location filename="../../mainwindow.ui" line="55"/>
         <source>&lt;i&gt;No application is currently playing audio.&lt;/i&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="61"/>
-        <location filename="../mainwindow.ui" line="120"/>
-        <location filename="../mainwindow.ui" line="179"/>
-        <location filename="../mainwindow.ui" line="238"/>
+        <location filename="../../mainwindow.ui" line="66"/>
+        <location filename="../../mainwindow.ui" line="131"/>
+        <location filename="../../mainwindow.ui" line="196"/>
+        <location filename="../../mainwindow.ui" line="261"/>
         <source>Show:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="69"/>
-        <location filename="../mainwindow.ui" line="128"/>
+        <location filename="../../mainwindow.ui" line="74"/>
+        <location filename="../../mainwindow.ui" line="139"/>
         <source>All Streams</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="74"/>
-        <location filename="../mainwindow.ui" line="133"/>
+        <location filename="../../mainwindow.ui" line="79"/>
+        <location filename="../../mainwindow.ui" line="144"/>
         <source>Applications</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="79"/>
-        <location filename="../mainwindow.ui" line="138"/>
+        <location filename="../../mainwindow.ui" line="84"/>
+        <location filename="../../mainwindow.ui" line="149"/>
         <source>Virtual Streams</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="88"/>
-        <source>_Recording</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="109"/>
+        <location filename="../../mainwindow.ui" line="120"/>
         <source>&lt;i&gt;No application is currently recording audio.&lt;/i&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="147"/>
-        <source>_Output Devices</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="168"/>
+        <location filename="../../mainwindow.ui" line="185"/>
         <source>&lt;i&gt;No output devices available&lt;/i&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="187"/>
+        <location filename="../../mainwindow.ui" line="204"/>
         <source>All Output Devices</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="192"/>
+        <location filename="../../mainwindow.ui" line="209"/>
         <source>Hardware Output Devices</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="197"/>
+        <location filename="../../mainwindow.ui" line="214"/>
         <source>Virtual Output Devices</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="206"/>
-        <source>_Input Devices</source>
+        <location filename="../../mainwindow.ui" line="28"/>
+        <source>&amp;Playback</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="227"/>
+        <location filename="../../mainwindow.ui" line="93"/>
+        <source>&amp;Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="158"/>
+        <source>&amp;Output Devices</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="223"/>
+        <source>&amp;Input Devices</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainwindow.ui" line="250"/>
         <source>&lt;i&gt;No input devices available&lt;/i&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="246"/>
+        <location filename="../../mainwindow.ui" line="269"/>
         <source>All Input Devices</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="251"/>
+        <location filename="../../mainwindow.ui" line="274"/>
         <source>All Except Monitors</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="256"/>
+        <location filename="../../mainwindow.ui" line="279"/>
         <source>Hardware Input Devices</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="261"/>
+        <location filename="../../mainwindow.ui" line="284"/>
         <source>Virtual Input Devices</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="266"/>
+        <location filename="../../mainwindow.ui" line="289"/>
         <source>Monitors</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="275"/>
-        <source>_Configuration</source>
+        <location filename="../../mainwindow.ui" line="298"/>
+        <source>&amp;Configuration</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="296"/>
+        <location filename="../../mainwindow.ui" line="325"/>
         <source>&lt;i&gt;No cards available for configuration&lt;/i&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="307"/>
+        <location filename="../../mainwindow.ui" line="336"/>
         <source>Show volume meters</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="318"/>
+        <location filename="../../mainwindow.ui" line="347"/>
         <source>...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="147"/>
-        <source>Error reading config file %s: %s</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cc" line="218"/>
-        <source>Error saving preferences</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cc" line="226"/>
-        <source>Error writing config file %s</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cc" line="261"/>
+        <location filename="../../mainwindow.cc" line="159"/>
         <source> (plugged in)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="265"/>
-        <location filename="../mainwindow.cc" line="359"/>
+        <location filename="../../mainwindow.cc" line="163"/>
+        <location filename="../../mainwindow.cc" line="257"/>
         <source> (unavailable)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="267"/>
-        <location filename="../mainwindow.cc" line="356"/>
+        <location filename="../../mainwindow.cc" line="165"/>
+        <location filename="../../mainwindow.cc" line="254"/>
         <source> (unplugged)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="498"/>
+        <location filename="../../mainwindow.cc" line="386"/>
         <source>Failed to read data from stream</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="542"/>
+        <location filename="../../mainwindow.cc" line="430"/>
         <source>Peak detect</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="543"/>
+        <location filename="../../mainwindow.cc" line="431"/>
         <source>Failed to create monitoring stream</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="558"/>
+        <location filename="../../mainwindow.cc" line="446"/>
         <source>Failed to connect monitoring stream</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="705"/>
+        <location filename="../../mainwindow.cc" line="585"/>
         <source>Ignoring sink-input due to it being designated as an event and thus handled by the Event widget</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="877"/>
+        <location filename="../../mainwindow.cc" line="757"/>
         <source>System Sounds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="1208"/>
+        <location filename="../../mainwindow.cc" line="1088"/>
         <source>Establishing connection to PulseAudio. Please wait...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -364,158 +356,159 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../pavucontrol.cc" line="60"/>
+        <location filename="../../pavucontrol.cc" line="67"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="81"/>
+        <location filename="../../pavucontrol.cc" line="88"/>
         <source>Card callback failure</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="104"/>
+        <location filename="../../pavucontrol.cc" line="111"/>
         <source>Sink callback failure</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="127"/>
+        <location filename="../../pavucontrol.cc" line="134"/>
         <source>Source callback failure</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="146"/>
+        <location filename="../../pavucontrol.cc" line="153"/>
         <source>Sink input callback failure</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="165"/>
+        <location filename="../../pavucontrol.cc" line="172"/>
         <source>Source output callback failure</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="205"/>
+        <location filename="../../pavucontrol.cc" line="212"/>
         <source>Client callback failure</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="221"/>
+        <location filename="../../pavucontrol.cc" line="228"/>
         <source>Server info callback failure</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="239"/>
-        <location filename="../pavucontrol.cc" line="536"/>
+        <location filename="../../pavucontrol.cc" line="246"/>
+        <location filename="../../pavucontrol.cc" line="543"/>
         <source>Failed to initialize stream_restore extension: %s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="257"/>
+        <location filename="../../pavucontrol.cc" line="264"/>
         <source>pa_ext_stream_restore_read() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="275"/>
-        <location filename="../pavucontrol.cc" line="550"/>
+        <location filename="../../pavucontrol.cc" line="282"/>
+        <location filename="../../pavucontrol.cc" line="557"/>
         <source>Failed to initialize device restore extension: %s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="296"/>
+        <location filename="../../pavucontrol.cc" line="303"/>
         <source>pa_ext_device_restore_read_sink_formats() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="314"/>
-        <location filename="../pavucontrol.cc" line="563"/>
+        <location filename="../../pavucontrol.cc" line="321"/>
+        <location filename="../../pavucontrol.cc" line="570"/>
         <source>Failed to initialize device manager extension: %s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="333"/>
+        <location filename="../../pavucontrol.cc" line="340"/>
         <source>pa_ext_device_manager_read() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="350"/>
+        <location filename="../../pavucontrol.cc" line="357"/>
         <source>pa_context_get_sink_info_by_index() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="363"/>
+        <location filename="../../pavucontrol.cc" line="370"/>
         <source>pa_context_get_source_info_by_index() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="376"/>
-        <location filename="../pavucontrol.cc" line="389"/>
+        <location filename="../../pavucontrol.cc" line="383"/>
+        <location filename="../../pavucontrol.cc" line="396"/>
         <source>pa_context_get_sink_input_info() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="402"/>
+        <location filename="../../pavucontrol.cc" line="409"/>
         <source>pa_context_get_client_info() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="412"/>
-        <location filename="../pavucontrol.cc" line="477"/>
+        <location filename="../../pavucontrol.cc" line="419"/>
+        <location filename="../../pavucontrol.cc" line="484"/>
         <source>pa_context_get_server_info() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="425"/>
+        <location filename="../../pavucontrol.cc" line="432"/>
         <source>pa_context_get_card_info_by_index() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="468"/>
+        <location filename="../../pavucontrol.cc" line="475"/>
         <source>pa_context_subscribe() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="484"/>
+        <location filename="../../pavucontrol.cc" line="491"/>
         <source>pa_context_client_info_list() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="491"/>
+        <location filename="../../pavucontrol.cc" line="498"/>
         <source>pa_context_get_card_info_list() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="498"/>
+        <location filename="../../pavucontrol.cc" line="505"/>
         <source>pa_context_get_sink_info_list() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="505"/>
+        <location filename="../../pavucontrol.cc" line="512"/>
         <source>pa_context_get_source_info_list() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="512"/>
+        <location filename="../../pavucontrol.cc" line="519"/>
         <source>pa_context_get_sink_input_info_list() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="519"/>
+        <location filename="../../pavucontrol.cc" line="526"/>
         <source>pa_context_get_source_output_info_list() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="578"/>
-        <location filename="../pavucontrol.cc" line="629"/>
+        <location filename="../../pavucontrol.cc" line="585"/>
+        <location filename="../../pavucontrol.cc" line="636"/>
         <source>Connection failed, attempting reconnect</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="601"/>
+        <location filename="../../pavucontrol.cc" line="608"/>
+        <location filename="../../pavucontrol.cc" line="668"/>
         <source>PulseAudio Volume Control</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="616"/>
+        <location filename="../../pavucontrol.cc" line="623"/>
         <source>Connection to PulseAudio failed. Automatic retry in 5s
 
 In this case this is likely because PULSE_SERVER in the Environment/X11 Root Window Properties
@@ -526,27 +519,22 @@ run start-pulseaudio-x11 manually.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="653"/>
+        <location filename="../../pavucontrol.cc" line="676"/>
         <source>Select a specific tab on load.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="659"/>
+        <location filename="../../pavucontrol.cc" line="679"/>
         <source>Retry forever if pa quits (every 5 seconds).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="666"/>
+        <location filename="../../pavucontrol.cc" line="682"/>
         <source>Maximize the window.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="672"/>
-        <source>Show version</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../pavucontrol.cc" line="695"/>
+        <location filename="../../pavucontrol.cc" line="707"/>
         <source>Fatal Error: Unable to connect to PulseAudio</source>
         <translation type="unfinished"></translation>
     </message>
@@ -554,7 +542,7 @@ run start-pulseaudio-x11 manually.</source>
 <context>
     <name>RoleWidget</name>
     <message>
-        <location filename="../rolewidget.cc" line="64"/>
+        <location filename="../../rolewidget.cc" line="59"/>
         <source>pa_ext_stream_restore_write() failed</source>
         <translation type="unfinished"></translation>
     </message>
@@ -562,32 +550,37 @@ run start-pulseaudio-x11 manually.</source>
 <context>
     <name>SinkInputWidget</name>
     <message>
-        <location filename="../sinkinputwidget.cc" line="34"/>
+        <location filename="../../sinkinputwidget.cc" line="36"/>
         <source>on</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sinkinputwidget.cc" line="52"/>
+        <location filename="../../sinkinputwidget.cc" line="39"/>
+        <source>Terminate Playback</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../sinkinputwidget.cc" line="53"/>
         <source>Unknown output</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sinkinputwidget.cc" line="63"/>
+        <location filename="../../sinkinputwidget.cc" line="64"/>
         <source>pa_context_set_sink_input_volume() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sinkinputwidget.cc" line="78"/>
+        <location filename="../../sinkinputwidget.cc" line="79"/>
         <source>pa_context_set_sink_input_mute() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sinkinputwidget.cc" line="88"/>
+        <location filename="../../sinkinputwidget.cc" line="89"/>
         <source>pa_context_kill_sink_input() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sinkinputwidget.cc" line="129"/>
+        <location filename="../../sinkinputwidget.cc" line="114"/>
         <source>pa_context_move_sink_input_by_index() failed</source>
         <translation type="unfinished"></translation>
     </message>
@@ -595,32 +588,27 @@ run start-pulseaudio-x11 manually.</source>
 <context>
     <name>SinkWidget</name>
     <message>
-        <location filename="../sinkwidget.cc" line="84"/>
+        <location filename="../../sinkwidget.cc" line="81"/>
         <source>pa_context_set_sink_volume_by_index() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sinkwidget.cc" line="99"/>
-        <source>Volume Control Feedback Sound</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../sinkwidget.cc" line="117"/>
+        <location filename="../../sinkwidget.cc" line="96"/>
         <source>pa_context_set_sink_mute_by_index() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sinkwidget.cc" line="131"/>
+        <location filename="../../sinkwidget.cc" line="110"/>
         <source>pa_context_set_default_sink() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sinkwidget.cc" line="147"/>
+        <location filename="../../sinkwidget.cc" line="126"/>
         <source>pa_context_set_sink_port_by_index() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sinkwidget.cc" line="187"/>
+        <location filename="../../sinkwidget.cc" line="166"/>
         <source>pa_ext_device_restore_save_sink_formats() failed</source>
         <translation type="unfinished"></translation>
     </message>
@@ -628,32 +616,37 @@ run start-pulseaudio-x11 manually.</source>
 <context>
     <name>SourceOutputWidget</name>
     <message>
-        <location filename="../sourceoutputwidget.cc" line="33"/>
+        <location filename="../../sourceoutputwidget.cc" line="36"/>
         <source>from</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sourceoutputwidget.cc" line="58"/>
+        <location filename="../../sourceoutputwidget.cc" line="39"/>
+        <source>Terminate Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../sourceoutputwidget.cc" line="60"/>
         <source>Unknown input</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sourceoutputwidget.cc" line="70"/>
+        <location filename="../../sourceoutputwidget.cc" line="72"/>
         <source>pa_context_set_source_output_volume() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sourceoutputwidget.cc" line="85"/>
+        <location filename="../../sourceoutputwidget.cc" line="87"/>
         <source>pa_context_set_source_output_mute() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sourceoutputwidget.cc" line="96"/>
+        <location filename="../../sourceoutputwidget.cc" line="98"/>
         <source>pa_context_kill_source_output() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sourceoutputwidget.cc" line="139"/>
+        <location filename="../../sourceoutputwidget.cc" line="125"/>
         <source>pa_context_move_source_output_by_index() failed</source>
         <translation type="unfinished"></translation>
     </message>
@@ -661,22 +654,22 @@ run start-pulseaudio-x11 manually.</source>
 <context>
     <name>SourceWidget</name>
     <message>
-        <location filename="../sourcewidget.cc" line="35"/>
+        <location filename="../../sourcewidget.cc" line="35"/>
         <source>pa_context_set_source_volume_by_index() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sourcewidget.cc" line="50"/>
+        <location filename="../../sourcewidget.cc" line="50"/>
         <source>pa_context_set_source_mute_by_index() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sourcewidget.cc" line="64"/>
+        <location filename="../../sourcewidget.cc" line="64"/>
         <source>pa_context_set_default_source() failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sourcewidget.cc" line="80"/>
+        <location filename="../../sourcewidget.cc" line="80"/>
         <source>pa_context_set_source_port_by_index() failed</source>
         <translation type="unfinished"></translation>
     </message>
@@ -684,37 +677,37 @@ run start-pulseaudio-x11 manually.</source>
 <context>
     <name>StreamWidget</name>
     <message>
-        <location filename="../streamwidget.ui" line="14"/>
+        <location filename="../../streamwidget.ui" line="14"/>
         <source>Form</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../streamwidget.ui" line="22"/>
-        <source>icon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../streamwidget.ui" line="36"/>
+        <location filename="../../streamwidget.ui" line="32"/>
         <source>Device Title</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../streamwidget.ui" line="43"/>
+        <location filename="../../streamwidget.ui" line="52"/>
         <source>direction</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../streamwidget.ui" line="50"/>
-        <source>Device</source>
+        <location filename="../../streamwidget.ui" line="59"/>
+        <source>device</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../streamwidget.ui" line="72"/>
-        <source>lock</source>
+        <location filename="../../streamwidget.ui" line="66"/>
+        <source>Mute audio</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../streamwidget.cc" line="49"/>
+        <location filename="../../streamwidget.ui" line="79"/>
+        <source>Lock channels together</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../streamwidget.cc" line="34"/>
         <source>Terminate</source>
         <translation type="unfinished"></translation>
     </message>
